summaryrefslogtreecommitdiffstats
path: root/khtml/dom
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /khtml/dom
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/dom')
-rw-r--r--khtml/dom/css_extensions.cpp6
-rw-r--r--khtml/dom/css_extensions.h8
-rw-r--r--khtml/dom/css_value.cpp8
-rw-r--r--khtml/dom/css_value.h2
-rw-r--r--khtml/dom/dom_doc.cpp4
-rw-r--r--khtml/dom/dom_node.h2
-rw-r--r--khtml/dom/dom_string.cpp18
-rw-r--r--khtml/dom/dom_string.h2
-rw-r--r--khtml/dom/html_block.h6
-rw-r--r--khtml/dom/html_element.cpp2
-rw-r--r--khtml/dom/html_form.h2
-rw-r--r--khtml/dom/html_image.cpp2
-rw-r--r--khtml/dom/html_image.h12
-rw-r--r--khtml/dom/html_inline.cpp2
-rw-r--r--khtml/dom/html_inline.h12
-rw-r--r--khtml/dom/html_table.h26
16 files changed, 57 insertions, 57 deletions
diff --git a/khtml/dom/css_extensions.cpp b/khtml/dom/css_extensions.cpp
index 23f7739dc..01a47d5f1 100644
--- a/khtml/dom/css_extensions.cpp
+++ b/khtml/dom/css_extensions.cpp
@@ -1881,15 +1881,15 @@ void CSS2Properties::setTop( const DOMString &value )
if(impl) ((ElementImpl *)impl)->setAttribute("top", value);
}
-DOMString CSS2Properties::unicodeBidi() const
+DOMString CSS2Properties::tqunicodeBidi() const
{
if(!impl) return 0;
- return ((ElementImpl *)impl)->getAttribute("unicodeBidi");
+ return ((ElementImpl *)impl)->getAttribute("tqunicodeBidi");
}
void CSS2Properties::setUnicodeBidi( const DOMString &value )
{
- if(impl) ((ElementImpl *)impl)->setAttribute("unicodeBidi", value);
+ if(impl) ((ElementImpl *)impl)->setAttribute("tqunicodeBidi", value);
}
DOMString CSS2Properties::verticalAlign() const
diff --git a/khtml/dom/css_value.cpp b/khtml/dom/css_value.cpp
index de450e861..20faff88a 100644
--- a/khtml/dom/css_value.cpp
+++ b/khtml/dom/css_value.cpp
@@ -126,7 +126,7 @@ void CSSStyleDeclaration::setProperty( const DOMString &propName, const DOMStrin
if (!id) return;
bool important = false;
TQString str = priority.string();
- if (str.find("important", 0, false) != -1)
+ if (str.tqfind("important", 0, false) != -1)
important = true;
static_cast<CSSStyleDeclarationImpl *>(impl)->setProperty( id, value, important );
@@ -500,17 +500,17 @@ RGBColor::~RGBColor()
CSSPrimitiveValue RGBColor::red() const
{
- return new CSSPrimitiveValueImpl(float(qAlpha(m_color) ? qRed(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
+ return new CSSPrimitiveValueImpl(float(tqAlpha(m_color) ? tqRed(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
}
CSSPrimitiveValue RGBColor::green() const
{
- return new CSSPrimitiveValueImpl(float(qAlpha(m_color) ? qGreen(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
+ return new CSSPrimitiveValueImpl(float(tqAlpha(m_color) ? tqGreen(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
}
CSSPrimitiveValue RGBColor::blue() const
{
- return new CSSPrimitiveValueImpl(float(qAlpha(m_color) ? qBlue(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
+ return new CSSPrimitiveValueImpl(float(tqAlpha(m_color) ? tqBlue(m_color) : 0), CSSPrimitiveValue::CSS_DIMENSION);
}
diff --git a/khtml/dom/css_value.h b/khtml/dom/css_value.h
index 5d4a043c7..7523a2797 100644
--- a/khtml/dom/css_value.h
+++ b/khtml/dom/css_value.h
@@ -633,7 +633,7 @@ class RectImpl;
/**
* The \c Rect interface is used to represent any <a
- * href="http://www.w3.org/TR/REC-CSS2/visufx.html#value-def-shape">
+ * href="http://www.w3.org/TR/REC-CSS2/visufx.html#value-def-tqshape">
* rect </a> value. This interface reflects the values in the
* underlying style property. Hence, modifications made through this
* interface modify the style property.
diff --git a/khtml/dom/dom_doc.cpp b/khtml/dom/dom_doc.cpp
index 0ff123444..088a7a94a 100644
--- a/khtml/dom/dom_doc.cpp
+++ b/khtml/dom/dom_doc.cpp
@@ -112,8 +112,8 @@ HTMLDocument DOMImplementation::createHTMLDocument( const DOMString& title )
r->open();
- r->write(TQString::fromLatin1("<HTML><HEAD><TITLE>") + title.string() +
- TQString::fromLatin1("</TITLE></HEAD>"));
+ r->write(TQString::tqfromLatin1("<HTML><HEAD><TITLE>") + title.string() +
+ TQString::tqfromLatin1("</TITLE></HEAD>"));
return r;
}
diff --git a/khtml/dom/dom_node.h b/khtml/dom/dom_node.h
index 37889eec2..4ddd4ffb1 100644
--- a/khtml/dom/dom_node.h
+++ b/khtml/dom/dom_node.h
@@ -875,7 +875,7 @@ public:
* not part of the DOM.
* @returns the element id, in case this is an element, 0 otherwise
*/
- Q_UINT32 elementId() const;
+ TQ_UINT32 elementId() const;
/**
* tests if this Node is 0. Useful especially, if casting to a derived
diff --git a/khtml/dom/dom_string.cpp b/khtml/dom/dom_string.cpp
index 14bdc2613..f8487cf5a 100644
--- a/khtml/dom/dom_string.cpp
+++ b/khtml/dom/dom_string.cpp
@@ -39,7 +39,7 @@ DOMString::DOMString(const TQString &str)
return;
}
- impl = new DOMStringImpl( str.unicode(), str.length() );
+ impl = new DOMStringImpl( str.tqunicode(), str.length() );
impl->ref();
}
@@ -193,10 +193,10 @@ bool DOMString::percentage(int &_percentage) const
return true;
}
-TQChar *DOMString::unicode() const
+TQChar *DOMString::tqunicode() const
{
if(!impl) return 0;
- return impl->unicode();
+ return impl->tqunicode();
}
TQString DOMString::string() const
@@ -225,8 +225,8 @@ bool DOM::strcasecmp( const DOMString &as, const DOMString &bs )
{
if ( as.length() != bs.length() ) return true;
- const TQChar *a = as.unicode();
- const TQChar *b = bs.unicode();
+ const TQChar *a = as.tqunicode();
+ const TQChar *b = bs.tqunicode();
if ( a == b ) return false;
if ( !( a && b ) ) return true;
int l = as.length();
@@ -239,7 +239,7 @@ bool DOM::strcasecmp( const DOMString &as, const DOMString &bs )
bool DOM::strcasecmp( const DOMString &as, const char* bs )
{
- const TQChar *a = as.unicode();
+ const TQChar *a = as.tqunicode();
int l = as.length();
if ( !bs ) return ( l != 0 );
while ( l-- ) {
@@ -265,7 +265,7 @@ bool DOM::operator==( const DOMString &a, const DOMString &b )
if( l != b.length() ) return false;
- if(!memcmp(a.unicode(), b.unicode(), l*sizeof(TQChar)))
+ if(!memcmp(a.tqunicode(), b.tqunicode(), l*sizeof(TQChar)))
return true;
return false;
}
@@ -276,7 +276,7 @@ bool DOM::operator==( const DOMString &a, const TQString &b )
if( l != b.length() ) return false;
- if(!memcmp(a.unicode(), b.unicode(), l*sizeof(TQChar)))
+ if(!memcmp(a.tqunicode(), b.tqunicode(), l*sizeof(TQChar)))
return true;
return false;
}
@@ -291,7 +291,7 @@ bool DOM::operator==( const DOMString &a, const char *b )
const TQChar *aptr = aimpl->s;
while ( alen-- ) {
unsigned char c = *b++;
- if ( !c || ( *aptr++ ).unicode() != c )
+ if ( !c || ( *aptr++ ).tqunicode() != c )
return false;
}
}
diff --git a/khtml/dom/dom_string.h b/khtml/dom/dom_string.h
index 3fe725f68..69f2f7b13 100644
--- a/khtml/dom/dom_string.h
+++ b/khtml/dom/dom_string.h
@@ -97,7 +97,7 @@ public:
*/
DOMString upper() const;
- TQChar *unicode() const;
+ TQChar *tqunicode() const;
TQString string() const;
int toInt() const;
diff --git a/khtml/dom/html_block.h b/khtml/dom/html_block.h
index 43be3660d..e57c311cd 100644
--- a/khtml/dom/html_block.h
+++ b/khtml/dom/html_block.h
@@ -105,7 +105,7 @@ public:
~HTMLDivElement();
/**
- * Horizontal text alignment. See the <a
+ * Horizontal text tqalignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -231,7 +231,7 @@ public:
~HTMLHeadingElement();
/**
- * Horizontal text alignment. See the <a
+ * Horizontal text tqalignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -272,7 +272,7 @@ public:
~HTMLParagraphElement();
/**
- * Horizontal text alignment. See the <a
+ * Horizontal text tqalignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
diff --git a/khtml/dom/html_element.cpp b/khtml/dom/html_element.cpp
index 0a2c15e53..0063985ea 100644
--- a/khtml/dom/html_element.cpp
+++ b/khtml/dom/html_element.cpp
@@ -177,7 +177,7 @@ HTMLCollection HTMLElement::all() const
void HTMLElement::assignOther( const Node &other, int elementId )
{
- if (other.elementId() != static_cast<Q_UINT32>(elementId)) {
+ if (other.elementId() != static_cast<TQ_UINT32>(elementId)) {
if ( impl ) impl->deref();
impl = 0;
} else {
diff --git a/khtml/dom/html_form.h b/khtml/dom/html_form.h
index 0623e421b..ef318ba06 100644
--- a/khtml/dom/html_form.h
+++ b/khtml/dom/html_form.h
@@ -798,7 +798,7 @@ public:
void setAccessKey( const DOMString & );
/**
- * Text alignment relative to \c FIELDSET . See the <a
+ * Text tqalignment relative to \c FIELDSET . See the <a
* href="http://www.w3.org/TR/REC-html40/interact/forms.html#adef-align-LEGEND">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
diff --git a/khtml/dom/html_image.cpp b/khtml/dom/html_image.cpp
index f7c9dac26..a5cdb3b71 100644
--- a/khtml/dom/html_image.cpp
+++ b/khtml/dom/html_image.cpp
@@ -122,7 +122,7 @@ void HTMLAreaElement::setNoHref( bool _noHref )
}
}
-DOMString HTMLAreaElement::shape() const
+DOMString HTMLAreaElement::tqshape() const
{
if(!impl) return DOMString();
return ((ElementImpl *)impl)->getAttribute(ATTR_SHAPE);
diff --git a/khtml/dom/html_inline.cpp b/khtml/dom/html_inline.cpp
index 568761685..9f40da2fb 100644
--- a/khtml/dom/html_inline.cpp
+++ b/khtml/dom/html_inline.cpp
@@ -148,7 +148,7 @@ void HTMLAnchorElement::setRev( const DOMString &value )
if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_REV, value);
}
-DOMString HTMLAnchorElement::shape() const
+DOMString HTMLAnchorElement::tqshape() const
{
if(!impl) return DOMString();
return ((ElementImpl *)impl)->getAttribute(ATTR_SHAPE);
diff --git a/khtml/dom/html_table.h b/khtml/dom/html_table.h
index c3a364d47..69d163723 100644
--- a/khtml/dom/html_table.h
+++ b/khtml/dom/html_table.h
@@ -63,7 +63,7 @@ public:
~HTMLTableCaptionElement();
/**
- * Caption alignment with respect to the table. See the <a
+ * Caption tqalignment with respect to the table. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-CAPTION">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -134,7 +134,7 @@ public:
void setAbbr( const DOMString & );
/**
- * Horizontal alignment of data in cell. See the <a
+ * Horizontal tqalignment of data in cell. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
*
@@ -187,7 +187,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of alignment character. See the <a
+ * Offset of tqalignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -281,7 +281,7 @@ public:
void setScope( const DOMString & );
/**
- * Vertical alignment of data in cell. See the <a
+ * Vertical tqalignment of data in cell. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -338,7 +338,7 @@ public:
~HTMLTableColElement();
/**
- * Horizontal alignment of cell data in column. See the <a
+ * Horizontal tqalignment of cell data in column. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
*
@@ -364,7 +364,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of alignment character. See the <a
+ * Offset of tqalignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -391,7 +391,7 @@ public:
void setSpan( long );
/**
- * Vertical alignment of cell data in column. See the <a
+ * Vertical tqalignment of cell data in column. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -790,7 +790,7 @@ public:
void setCells( const HTMLCollection & );
/**
- * Horizontal alignment of data within cells of this row. See the
+ * Horizontal tqalignment of data within cells of this row. See the
* <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
@@ -831,7 +831,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of alignment character. See the <a
+ * Offset of tqalignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -844,7 +844,7 @@ public:
void setChOff( const DOMString & );
/**
- * Vertical alignment of data within cells of this row. See the <a
+ * Vertical tqalignment of data within cells of this row. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -913,7 +913,7 @@ public:
~HTMLTableSectionElement();
/**
- * Horizontal alignment of data in cells. See the \c align
+ * Horizontal tqalignment of data in cells. See the \c align
* attribute for HTMLTheadElement for details.
*
*/
@@ -938,7 +938,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of alignment character. See the <a
+ * Offset of tqalignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -951,7 +951,7 @@ public:
void setChOff( const DOMString & );
/**
- * Vertical alignment of data in cells. See the \c valign
+ * Vertical tqalignment of data in cells. See the \c valign
* attribute for HTMLTheadElement for details.
*
*/
diff --git a/khtml/dom/css_extensions.h b/khtml/dom/css_extensions.h
index a6cdb2149..bda2cfbbc 100644
--- a/khtml/dom/css_extensions.h
+++ b/khtml/dom/css_extensions.h
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
* href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-unicode-bidi">
* unicode-bidi property definition </a> in CSS2.
*
*/
- DOM::DOMString unicodeBidi() const;
+ DOM::DOMString tqunicodeBidi() const;
/**
- * see unicodeBidi
+ * see tqunicodeBidi
*/
void setUnicodeBidi( const DOM::DOMString & );
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
- * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-unicode-bidi">
- * unicode-bidi property definition </a> in CSS2.
+ * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
+ * tqunicode-bidi property definition </a> in CSS2.
*
*/
diff --git a/khtml/dom/html_image.h b/khtml/dom/html_image.h
index 9f30aaa14..9b1334c83 100644
--- a/khtml/dom/html_image.h
+++ b/khtml/dom/html_image.h
@@ -90,7 +90,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
* geometry. See also \c shape for the shape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
* coords attribute definition </a> in HTML 4.0.
@@ -131,16 +131,16 @@ public:
void setNoHref( bool );
/**
* The shape of the active area. The coordinates are given by
* \c coords . See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
* shape attribute definition </a> in HTML 4.0.
*
*/
- DOMString shape() const;
+ DOMString tqshape() const;
/**
- * see shape
+ * see tqshape
*/
void setShape( const DOMString & );
@@ -90,7 +90,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
- * geometry. See also \c shape for the shape of the
+ * geometry. See also \c tqshape for the tqshape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
@@ -131,16 +131,16 @@ public:
void setNoHref( bool );
/**
- * The shape of the active area. The coordinates are given by
+ * The tqshape of the active area. The coordinates are given by
* \c coords . See the <a
@@ -131,16 +131,16 @@ public:
* \c coords . See the <a
- * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
- * shape attribute definition </a> in HTML 4.0.
+ * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
+ * tqshape attribute definition </a> in HTML 4.0.
*
*/
diff --git a/khtml/dom/html_inline.h b/khtml/dom/html_inline.h
index 6c1b2d2a2..d5c11d515 100644
--- a/khtml/dom/html_inline.h
+++ b/khtml/dom/html_inline.h
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
* geometry. See also \c shape for the shape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
* coords attribute definition </a> in HTML 4.0.
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
* The shape of the active area. The coordinates are given by
* \c coords . See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
* shape attribute definition </a> in HTML 4.0.
*
*/
- DOMString shape() const;
+ DOMString tqshape() const;
/**
- * see shape
+ * see tqshape
*/
void setShape( const DOMString & );
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
- * geometry. See also \c shape for the shape of the
+ * geometry. See also \c tqshape for the tqshape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
- * The shape of the active area. The coordinates are given by
+ * The tqshape of the active area. The coordinates are given by
* \c coords . See the <a
@@ -168,16 +168,16 @@ public:
* \c coords . See the <a
- * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
- * shape attribute definition </a> in HTML 4.0.
+ * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
+ * tqshape attribute definition </a> in HTML 4.0.
*
*/